"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RuleResolver_1 = require("./resolver/RuleResolver");
const RuleAppliedResult_1 = require("./core/RuleAppliedResult");
const LayerRuleBindings_1 = require("./core/LayerRuleBindings");
class DLintRule {
    constructor(bindings) {
        this.bindings = new LayerRuleBindings_1.LayerRuleBindings(bindings);
    }
    apply(layer) {
        const { bindings } = this;
        const { layers } = bindings;
        if (!layers.has(layer.name)) {
            throw new Error(`Layer "${layer.name}" not found in DLintRule`);
        }
        const expressions = bindings.expressionFor(layer);
        const units = expressions.map((exp) => new RuleResolver_1.RuleResolver(layer, layers).resolve(exp));
        const disallowed = layer.nodes
            .map((node) => {
            const results = units.map((unit) => unit.apply(node));
            return RuleAppliedResult_1.reduceDisallowedResults(layer, node, results);
        })
            .filter(({ statuses }) => statuses.length > 0);
        return disallowed;
    }
}
exports.DLintRule = DLintRule;
