"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@dlint/core");
var RuleAllowanceStatus;
(function (RuleAllowanceStatus) {
    RuleAllowanceStatus["ALLOWED"] = "allowed";
    RuleAllowanceStatus["DISALLOWED"] = "disallowed";
})(RuleAllowanceStatus = exports.RuleAllowanceStatus || (exports.RuleAllowanceStatus = {}));
/**
 * Result of applying a specific rule unit to a DLintNode
 */
class NodeAppliedResult {
    constructor(node, ruleUnitName) {
        this.node = node;
        this.ruleUnitName = ruleUnitName;
        this.moduleStatusMap = new core_1.ObjectKeyMap(core_1.DLintModuleUtil.toKeyString);
    }
    allow(module) {
        this.moduleStatusMap.set(module, {
            status: RuleAllowanceStatus.ALLOWED,
            ruleUnitName: this.ruleUnitName,
            module,
        });
    }
    disallow(module) {
        this.moduleStatusMap.set(module, {
            status: RuleAllowanceStatus.DISALLOWED,
            ruleUnitName: this.ruleUnitName,
            module,
        });
    }
    statuses() {
        return this.moduleStatusMap.values();
    }
}
exports.NodeAppliedResult = NodeAppliedResult;
/**
 * Reduce NodeAppliedResult array to single result
 */
exports.reduceDisallowedResults = (layer, node, results) => {
    if (results.length === 0) {
        return {
            layer,
            node,
            statuses: [],
        };
    }
    const invalidResult = results.find((result) => result.node.file.absolutePath !== node.file.absolutePath);
    if (invalidResult) {
        throw new Error(`Different node: ${results[0].node.file.absolutePath} != ${invalidResult.node.file.absolutePath}`);
    }
    const map = new core_1.ObjectKeyMap(core_1.DLintModuleUtil.toKeyString);
    for (const result of results) {
        for (const status of result.statuses()) {
            map.set(status.module, status);
        }
    }
    return {
        layer,
        node,
        statuses: map
            .values()
            .filter((module) => module.status === RuleAllowanceStatus.DISALLOWED),
    };
};
