"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const core_1 = require("@dlint/core");
const RuleUnitBase_1 = require("./RuleUnitBase");
// --- allowing rule units
class AllowAll extends RuleUnitBase_1.RuleUnitBase {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.AllowAll;
        this.positive = true;
    }
    target(fanout) {
        return [...fanout.locals, ...fanout.builtins, ...fanout.packages];
    }
    judge() {
        return true;
    }
}
exports.AllowAll = AllowAll;
class AllowAllLayers extends RuleUnitBase_1.RuleUnitBase {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.AllowAllLayers;
        this.positive = true;
    }
    target(fanout) {
        // includes self
        return [...fanout.locals];
    }
    judge() {
        return true;
    }
}
exports.AllowAllLayers = AllowAllLayers;
class AllowAllPackages extends RuleUnitBase_1.RuleUnitBase {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.AllowAllPackages;
        this.positive = true;
    }
    target(fanout) {
        return [...fanout.builtins, ...fanout.packages];
    }
    judge() {
        return true;
    }
}
exports.AllowAllPackages = AllowAllPackages;
class AllowAllNodejs extends RuleUnitBase_1.RuleUnitBase {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.AllowAllNodejs;
        this.positive = true;
    }
    target(fanout) {
        return [...fanout.builtins];
    }
    judge() {
        return true;
    }
}
exports.AllowAllNodejs = AllowAllNodejs;
class AllowAllJson extends RuleUnitBase_1.RuleUnitBase {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.AllowAllJson;
        this.positive = true;
    }
    target(fanout) {
        return [...fanout.locals];
    }
    judge(module) {
        return path_1.extname(module.path.relativePath) === '.json';
    }
}
exports.AllowAllJson = AllowAllJson;
class AllowLayers extends RuleUnitBase_1.RuleUnitBase {
    constructor(layers) {
        super();
        this.name = core_1.RuleUnitName.AllowLayers;
        this.positive = true;
        this.layers = layers;
    }
    target(fanout) {
        return [...fanout.locals];
    }
    judge(module) {
        return this.layers.some((layer) => layer.has(module));
    }
}
exports.AllowLayers = AllowLayers;
class AllowPackages extends RuleUnitBase_1.RuleUnitBase {
    constructor(packages) {
        super();
        this.name = core_1.RuleUnitName.AllowPackages;
        this.positive = true;
        this.packages = packages;
    }
    target(fanout) {
        return [...fanout.packages, ...fanout.builtins];
    }
    judge(module) {
        return this.packages.includes(module.name);
    }
}
exports.AllowPackages = AllowPackages;
class AllowSelfLayer extends RuleUnitBase_1.RuleUnitBase {
    constructor(selfLayer) {
        super();
        this.name = core_1.RuleUnitName.AllowSelfLayer;
        this.positive = true;
        this.selfLayer = selfLayer;
    }
    target(fanout) {
        return [...fanout.locals];
    }
    judge(module) {
        return this.selfLayer.has(module);
    }
}
exports.AllowSelfLayer = AllowSelfLayer;
// --- disallowing rule units
class DisallowAll extends AllowAll {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowAll;
        this.positive = false;
    }
}
exports.DisallowAll = DisallowAll;
class DisallowLayers extends AllowLayers {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowLayers;
        this.positive = false;
    }
}
exports.DisallowLayers = DisallowLayers;
class DisallowPackages extends AllowPackages {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowPackages;
        this.positive = false;
    }
}
exports.DisallowPackages = DisallowPackages;
class DisallowAllLayers extends AllowAllLayers {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowAllLayers;
        this.positive = false;
    }
}
exports.DisallowAllLayers = DisallowAllLayers;
class DisallowAllPackages extends AllowAllPackages {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowAllPackages;
        this.positive = false;
    }
}
exports.DisallowAllPackages = DisallowAllPackages;
class DisallowAllNodejs extends AllowAllNodejs {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowAllNodejs;
        this.positive = false;
    }
}
exports.DisallowAllNodejs = DisallowAllNodejs;
class DisallowAllJson extends AllowAllJson {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowAllJson;
        this.positive = false;
    }
}
exports.DisallowAllJson = DisallowAllJson;
class DisallowSelfLayer extends AllowSelfLayer {
    constructor() {
        super(...arguments);
        this.name = core_1.RuleUnitName.DisallowSelfLayer;
        this.positive = false;
    }
}
exports.DisallowSelfLayer = DisallowSelfLayer;
